==> deepin-ocr_6.5.0.tar.xz: BUILD/translations/deepin-ocr_fa.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fa">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="115"/>
        <source>No text recognized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>Recognize language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>Simplified Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="204"/>
        <source>Copy text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="210"/>
        <source>Save as TXT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="236"/>
        <source>Undo (Ctrl+Z)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="247"/>
        <source>Redo (Ctrl+Shift+Z)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="294"/>
        <location filename="../src/mainwidget.cpp" line="335"/>
        <source>Recognizing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="563"/>
        <source>Copied</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="75"/>
        <source>OCR Tool</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="24"/>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="27"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="29"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="283"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-ocr_6.5.6.tar.xz: BUILD/translations/deepin-ocr_fa.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fa">
<context>
    <name>MainWidget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="115"/>
        <source>No text recognized</source>
        <translation>متنی شناسایی نشد</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="166"/>
        <source>Recognize language</source>
        <translation>زبان را شناسایی کن</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>Simplified Chinese</source>
        <translation>چینی ساده</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>English</source>
        <translation>انگلیسی</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="169"/>
        <source>Traditional Chinese</source>
        <translation>چینی سنتی</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="204"/>
        <source>Copy text</source>
        <translation>متن را کپی کن</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="210"/>
        <source>Save as TXT</source>
        <translation>ذخیره به عنوان TXT</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="236"/>
        <source>Undo (Ctrl+Z)</source>
        <translation>لغو (کنترل + Z)</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="247"/>
        <source>Redo (Ctrl+Shift+Z)</source>
        <translation>تکرار (کنترل + Shift + Z)</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="294"/>
        <source>Recognizing</source>
        <translation>در حال شناسایی</translation>
    </message>
    <message>
        <location filename="../src/mainwidget.cpp" line="563"/>
        <source>Copied</source>
        <translation>کپی شد</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="75"/>
        <source>OCR Tool</source>
        <translation>اِسِکرِیِن تُول</translation>
    </message>
</context>
<context>
    <name>ResultTextView</name>
    <message>
        <location filename="../src/resulttextview.cpp" line="22"/>
        <source>Copy</source>
        <translation>کپی</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="24"/>
        <source>Cut</source>
        <translation>برید</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="27"/>
        <source>Select All</source>
        <translation>همه را انتخاب کن</translation>
    </message>
    <message>
        <location filename="../src/resulttextview.cpp" line="29"/>
        <source>Paste</source>
        <translation>چسباندن</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="../src/mainwidget.cpp" line="283"/>
        <source>Tips: The clearer the image is, the more accurate the text is</source>
        <translation>نکته: تصویر پاکتری باشد، متن دقیقتری خواهد بود</translation>
    </message>
</context>
</TS>
